function obj=eye(varargin)
% FUNCTION fc_amat.eye
% -- eye(N,m) or eye(N,m,classname)
%      Return an N-by-m-by-m amat object where each of its N matrices are the m-by-m identity
%      matrix. 
%    
% -- eye([N,m,n]) or eye([N,m,n],classname)
% -- eye(N,m,n) or eye(N,m,n,classname)
%      Return an N-by-m-by-n amat object where each of its N matrices are the m-by-n matrix
%      with 1's on diagonal and 0's elsewhere.
%
%      Optional classname argument can be used for setting amat object data 
%      type (default 'double').
%
%      See also: fc_amat.ones, fc_amat.zeros, 
%                fc_amat.random.rand, fc_amat.random.randn
%
  classname='double';
  assert( ismember(nargin,[1,2,3,4]) )
  n=nargin;
  if ischar(varargin{end})
    classname=varargin{end};
    n=n-1;
  end
  switch n
    case 1 % varargin={[N,m,n]} or varargin={[N,m,n],classname}
      S=varargin{1}; assert(length(S)==3)
      N=S(1);m=S(2);n=S(3);
    case 2 % varargin={N,m} or % varargin={N,m,classname}
        N=varargin{1};m=varargin{2};n=m;
    case 3  % varargin={N,m,n} or % varargin={N,m,n,classname}
      N=varargin{1};
      m=varargin{2};
      n=varargin{3};
  end
  obj=amat(N,m,n,classname); % N-dimensional arrays are not supported with eye function
  t=ones(N,1,classname);
  for i=1:min(m,n)
    obj(i,i)=t;
  end
end

